@@ -60,9 +60,6 @@
 
 #include "misc.h"
 
-#define DOC_X_POS(x) (int(float(x) / Scale) + ViewX1)
-#define DOC_Y_POS(y) (int(float(y) / Scale) + ViewY1)
-
 // just dummies for empty lists
 Q3PtrList<Wire> SymbolWires;
 Q3PtrList<Node> SymbolNodes;
@@ -553,10 +550,9 @@ void Schematic::PostPaintEvent(
 // ---------------------------------------------------
 void Schematic::contentsMouseMoveEvent(QMouseEvent *Event)
 {
-    auto x = Event->pos().x();
-    auto y = Event->pos().y();
-    auto xpos = DOC_X_POS(x);
-    auto ypos = DOC_Y_POS(y);
+    const QPoint modelPos = contentsToModel(Event->pos());
+    auto xpos = modelPos.x();
+    auto ypos = modelPos.y();
     QString text = "";
 
     auto doubleToString = [](bool condition, double number) {
@@ -629,14 +625,13 @@ void Schematic::contentsMousePressEvent(QMouseEvent *Event)
     if (App->MouseReleaseAction == &MouseActions::MReleasePaste)
         return;
 
-    float x = float(Event->pos().x()) / Scale + float(ViewX1);
-    float y = float(Event->pos().y()) / Scale + float(ViewY1);
+    const QPoint inModel = contentsToModel(Event->pos());
 
     if (Event->button() == Qt::RightButton)
         if (App->MousePressAction != &MouseActions::MPressElement)
             if (App->MousePressAction != &MouseActions::MPressWire2) {
                 // show menu on right mouse button
-                App->view->rightPressMenu(this, Event, x, y);
+                App->view->rightPressMenu(this, Event, inModel.x(), inModel.y());
                 if (App->MouseReleaseAction)
                     // Is not called automatically because menu has focus.
                     (App->view->*(App->MouseReleaseAction))(this, Event);
@@ -652,7 +647,7 @@ void Schematic::contentsMousePressEvent(QMouseEvent *Event)
     }
 
     if (App->MousePressAction)
-        (App->view->*(App->MousePressAction))(this, Event, x, y);
+        (App->view->*(App->MousePressAction))(this, Event, inModel.x(), inModel.y());
 }
 
 // -----------------------------------------------------------
@@ -939,14 +934,10 @@ void Schematic::zoomToSelection() {
                     return;
                 }
 
-    // Coordinates of top-left and bottom-right corners of the selected
-    // elements bounding rectangle
-    int selectedX1, selectedX2, selectedY1, selectedY2 = 0;
-    sizeOfSelection(selectedX1, selectedY1, selectedX2, selectedY2);
+    const QRect selectedBoundingRect{ sizeOfSelection() };
 
     // Working with raw coordinates is clumsy, abstract them out
     const QRect usedBoundingRect{UsedX1, UsedY1, UsedX2 - UsedX1, UsedY2 - UsedY1};
-    const QRect selectedBoundingRect{selectedX1, selectedY1, selectedX2 - selectedX1, selectedY2 - selectedY1};
 
     if (selectedBoundingRect.width() == 0 || selectedBoundingRect.height() == 0) {
         // If nothing is selected, then what should be shown? Probably it's best
@@ -1045,6 +1036,12 @@ void Schematic::showNoZoom()
     renderModel(Scale, newModel, displayedInCenter, vpCenter);
  }
 
+ QPoint Schematic::setOnGrid(const QPoint& p) {
+   QPoint snappedToGrid{p.x(), p.y()};
+   setOnGrid(snappedToGrid.rx(), snappedToGrid.ry());
+   return snappedToGrid;
+ }
+
 // ---------------------------------------------------
 // Sets an arbitrary coordinate onto the next grid coordinate.
 void Schematic::setOnGrid(int &x, int &y)
@@ -1074,7 +1071,7 @@ void Schematic::drawGrid(const ViewPainter& p)
 
     {
         // Draw small cross at origin of coordinates
-        const QPoint origin = contentsToViewport(modelToView(QPoint{0, 0}));
+        const QPoint origin = modelToViewport(QPoint{0, 0});
         p.Painter->drawLine(origin.x() - 3, origin.y(), origin.x() + 4, origin.y());  // horizontal stick
         p.Painter->drawLine(origin.x(), origin.y() - 3, origin.x(), origin.y() + 4);  // vertical stick
     }
@@ -1096,18 +1093,11 @@ void Schematic::drawGrid(const ViewPainter& p)
     // grid-nodes should be drawn — where to start and where to finish drawing
     // these nodes.
 
-    // Find a point displayed in top-left corner
-    QPoint gridTopLeft = viewportToModel(viewportRect().topLeft());
-    // Set its coordinates to coordinates of nearest grid-point
-    setOnGrid(gridTopLeft.rx(), gridTopLeft.ry());
-    // Convert coordinates from model back to viewport
-    gridTopLeft = modelToView(gridTopLeft);
-    gridTopLeft = contentsToViewport(gridTopLeft);
+    QPoint topLeft = viewportToModel(viewportRect().topLeft());
+    const QPoint gridTopLeft = modelToViewport(setOnGrid(topLeft));
 
-    QPoint gridBottomRight = viewportToModel(viewportRect().bottomRight());
-    setOnGrid(gridBottomRight.rx(), gridBottomRight.ry());
-    gridBottomRight = modelToView(gridBottomRight);
-    gridBottomRight = contentsToViewport(gridBottomRight);
+    QPoint bottomRight = viewportToModel(viewportRect().bottomRight());
+    const QPoint gridBottomRight = modelToViewport(setOnGrid(bottomRight));
 
     // This is the minimal distance between drawn grid-nodes. No matter how
     // a user scales the view, any two adjacent nodes must have at least this
@@ -1149,6 +1139,26 @@ float Schematic::textCorr()
     Font.setPointSizeF(Scale * float(Font.pointSize()));
     // use the screen-compatible metric
     QFontMetrics metrics(Font, 0);
+    // Line spacing is the distance from one base line to the next
+    // and I think it's obvious that line spacing value somehow depends on
+    // font size.
+    // For simplicity let's say that this dependency has the form of
+    // a coefficient <k>, i.e. line spacing is equal to
+    //   fontSize * k.
+    //
+    // Then:
+    //   metrics.lineSpacing = (Scale * QucsSettings.font.pointSize()) * k
+    //
+    // And then the value returned here is a fraction:
+    //                   Scale
+    //   ———————————————————————————————————————————
+    //   (Scale * QucsSettings.font.pointSize()) * k
+    //
+    // Which is equal to one divided by original, n o t - s c a l e d
+    // lines spacing:
+    //                 1
+    //   —————————————————————————————————
+    //   QucsSettings.font.pointSize() * k
     return (Scale / float(metrics.lineSpacing()));
 }
 
@@ -1159,261 +1169,184 @@ void Schematic::sizeOfAll(int &xmin, int &ymin, int &xmax, int &ymax)
     ymin = INT_MAX;
     xmax = INT_MIN;
     ymax = INT_MIN;
-    Component *pc;
-    Diagram *pd;
-    Wire *pw;
-    WireLabel *pl;
-    Painting *pp;
 
-    if (Components->isEmpty())
-        if (Wires->isEmpty())
-            if (Diagrams->isEmpty())
-                if (Paintings->isEmpty()) {
-                    xmin = xmax = 0;
-                    ymin = ymax = 0;
-                    return;
-                }
+    if (Components->isEmpty() && Wires->isEmpty() && Diagrams->isEmpty() && Paintings->isEmpty()) {
+        xmin = xmax = 0;
+        ymin = ymax = 0;
+        return;
+    }
 
-    float Corr = textCorr();
     int x1, y1, x2, y2;
     // find boundings of all components
-    for (pc = Components->first(); pc != 0; pc = Components->next()) {
-        pc->entireBounds(x1, y1, x2, y2, Corr);
-        if (x1 < xmin)
-            xmin = x1;
-        if (x2 > xmax)
-            xmax = x2;
-        if (y1 < ymin)
-            ymin = y1;
-        if (y2 > ymax)
-            ymax = y2;
+    for (auto* pc : *Components) {
+        pc->entireBounds(x1, y1, x2, y2);
+        xmin = std::min(x1, xmin);
+        xmax = std::max(x2, xmax);
+        ymin = std::min(y1, ymin);
+        ymax = std::max(y2, ymax);
     }
 
     // find boundings of all wires
-    for (pw = Wires->first(); pw != 0; pw = Wires->next()) {
-        if (pw->x1 < xmin)
-            xmin = pw->x1;
-        if (pw->x2 > xmax)
-            xmax = pw->x2;
-        if (pw->y1 < ymin)
-            ymin = pw->y1;
-        if (pw->y2 > ymax)
-            ymax = pw->y2;
+    for (auto* pw : *Wires) {
+        xmin = std::min(pw->x1, xmin);
+        xmax = std::max(pw->x2, xmax);
+        ymin = std::min(pw->y1, ymin);
+        ymax = std::max(pw->y2, ymax);
 
-        pl = pw->Label;
-        if (pl) { // check position of wire label
+        if (auto* pl = pw->Label; pl) { // check position of wire label
             pl->getLabelBounding(x1, y1, x2, y2);
-            if (x1 < xmin)
-                xmin = x1;
-            if (x2 > xmax)
-                xmax = x2;
-            if (y1 < ymin)
-                ymin = y1;
-            if (y2 > ymax)
-                ymax = y2;
+            xmin = std::min(x1, xmin);
+            xmax = std::max(x2, xmax);
+            ymin = std::min(y1, ymin);
+            ymax = std::max(y2, ymax);
         }
     }
 
     // find boundings of all node labels
-    for (Node *pn = Nodes->first(); pn != 0; pn = Nodes->next()) {
-        pl = pn->Label;
-        if (pl) { // check position of node label
+    for (auto* pn : *Nodes) {
+        if (auto* pl = pn->Label; pl) { // check position of node label
             pl->getLabelBounding(x1, y1, x2, y2);
-            if (x1 < xmin)
-                xmin = x1;
-            if (x2 > xmax)
-                xmax = x2;
-            if (y1 < ymin)
-                ymin = y1;
-            if (y2 > ymax)
-                ymax = y2;
+            xmin = std::min(x1, xmin);
+            xmax = std::max(x2, xmax);
+            ymin = std::min(y1, ymin);
+            ymax = std::max(y2, ymax);
         }
     }
 
     // find boundings of all diagrams
-    for (pd = Diagrams->first(); pd != 0; pd = Diagrams->next()) {
+    for (auto* pd : *Diagrams) {
         pd->Bounding(x1, y1, x2, y2);
-        if (x1 < xmin)
-            xmin = x1;
-        if (x2 > xmax)
-            xmax = x2;
-        if (y1 < ymin)
-            ymin = y1;
-        if (y2 > ymax)
-            ymax = y2;
+        xmin = std::min(x1, xmin);
+        xmax = std::max(x2, xmax);
+        ymin = std::min(y1, ymin);
+        ymax = std::max(y2, ymax);
 
-        for (Graph *pg : pd->Graphs)
+        for (auto* pg : pd->Graphs)
             // test all markers of diagram
-            for (Marker *pm : pg->Markers) {
+            for (auto* pm : pg->Markers) {
                 pm->Bounding(x1, y1, x2, y2);
-                if (x1 < xmin)
-                    xmin = x1;
-                if (x2 > xmax)
-                    xmax = x2;
-                if (y1 < ymin)
-                    ymin = y1;
-                if (y2 > ymax)
-                    ymax = y2;
+                xmin = std::min(x1, xmin);
+                xmax = std::max(x2, xmax);
+                ymin = std::min(y1, ymin);
+                ymax = std::max(y2, ymax);
             }
     }
 
     // find boundings of all Paintings
-    for (pp = Paintings->first(); pp != nullptr; pp = Paintings->next()) {
+    for (auto* pp : *Paintings) {
         pp->Bounding(x1, y1, x2, y2);
-        if (x1 < xmin)
-            xmin = x1;
-        if (x2 > xmax)
-            xmax = x2;
-        if (y1 < ymin)
-            ymin = y1;
-        if (y2 > ymax)
-            ymax = y2;
+        xmin = std::min(x1, xmin);
+        xmax = std::max(x2, xmax);
+        ymin = std::min(y1, ymin);
+        ymax = std::max(y2, ymax);
     }
 }
 
-void Schematic::sizeOfSelection(int &xmin, int &ymin, int &xmax, int &ymax)
-{
-    xmin = INT_MAX;
-    ymin = INT_MAX;
-    xmax = INT_MIN;
-    ymax = INT_MIN;
-    Component *pc;
-    Diagram *pd;
-    Wire *pw;
-    WireLabel *pl;
-    Painting *pp;
+QRect Schematic::sizeOfSelection() const {
+    int xmin = INT_MAX;
+    int ymin = INT_MAX;
+    int xmax = INT_MIN;
+    int ymax = INT_MIN;
 
     bool isAnySelected = false;
 
-    if (Components->isEmpty())
-        if (Wires->isEmpty())
-            if (Diagrams->isEmpty())
-                if (Paintings->isEmpty()) {
-                    xmin = xmax = 0;
-                    ymin = ymax = 0;
-                    return;
-                }
+    if (Components->isEmpty() && Wires->isEmpty() && Diagrams->isEmpty() &&
+        Paintings->isEmpty()) {
+        return QRect{};
+    }
 
-    float Corr = textCorr();
     int x1, y1, x2, y2;
     // find boundings of all components
-    for (pc = Components->first(); pc != 0; pc = Components->next()) {
+    for (auto* pc : *Components) {
         if (!pc->isSelected) {
             continue;
         }
         isAnySelected = true;
-        pc->entireBounds(x1, y1, x2, y2, Corr);
-        if (x1 < xmin)
-            xmin = x1;
-        if (x2 > xmax)
-            xmax = x2;
-        if (y1 < ymin)
-            ymin = y1;
-        if (y2 > ymax)
-            ymax = y2;
+        pc->entireBounds(x1, y1, x2, y2);
+        xmin = std::min(x1, xmin);
+        xmax = std::max(x2, xmax);
+        ymin = std::min(y1, ymin);
+        ymax = std::max(y2, ymax);
     }
 
     // find boundings of all wires
-    for (pw = Wires->first(); pw != 0; pw = Wires->next()) {
+    for (auto* pw : *Wires) {
         if (!pw->isSelected) {
             continue;
         }
         isAnySelected = true;
-        if (pw->x1 < xmin)
-            xmin = pw->x1;
-        if (pw->x2 > xmax)
-            xmax = pw->x2;
-        if (pw->y1 < ymin)
-            ymin = pw->y1;
-        if (pw->y2 > ymax)
-            ymax = pw->y2;
+        xmin          = std::min(pw->x1, xmin);
+        xmax          = std::max(pw->x2, xmax);
+        ymin          = std::min(pw->y1, ymin);
+        ymax          = std::max(pw->y2, ymax);
 
-        pl = pw->Label;
-        if (pl) { // check position of wire label
+        if (auto* pl = pw->Label; pl) { // check position of wire label
             pl->getLabelBounding(x1, y1, x2, y2);
-            if (x1 < xmin)
-                xmin = x1;
-            if (x2 > xmax)
-                xmax = x2;
-            if (y1 < ymin)
-                ymin = y1;
-            if (y2 > ymax)
-                ymax = y2;
+            xmin = std::min(x1, xmin);
+            xmax = std::max(x2, xmax);
+            ymin = std::min(y1, ymin);
+            ymax = std::max(y2, ymax);
         }
     }
 
     // find boundings of all node labels
-    for (Node *pn = Nodes->first(); pn != 0; pn = Nodes->next()) {
+    for (auto* pn : *Nodes) {
         if (!pn->isSelected) {
             continue;
         }
-        pl = pn->Label;
-        if (pl) { // check position of node label
+
+        if (auto* pl = pn->Label; pl) { // check position of node label
             isAnySelected = true;
             pl->getLabelBounding(x1, y1, x2, y2);
-            if (x1 < xmin)
-                xmin = x1;
-            if (x2 > xmax)
-                xmax = x2;
-            if (y1 < ymin)
-                ymin = y1;
-            if (y2 > ymax)
-                ymax = y2;
+            xmin = std::min(x1, xmin);
+            xmax = std::max(x2, xmax);
+            ymin = std::min(y1, ymin);
+            ymax = std::max(y2, ymax);
         }
     }
 
     // find boundings of all diagrams
-    for (pd = Diagrams->first(); pd != 0; pd = Diagrams->next()) {
+    for (auto* pd : *Diagrams) {
         if (!pd->isSelected) {
             continue;
         }
         isAnySelected = true;
         pd->Bounding(x1, y1, x2, y2);
-        if (x1 < xmin)
-            xmin = x1;
-        if (x2 > xmax)
-            xmax = x2;
-        if (y1 < ymin)
-            ymin = y1;
-        if (y2 > ymax)
-            ymax = y2;
+        xmin = std::min(x1, xmin);
+        xmax = std::max(x2, xmax);
+        ymin = std::min(y1, ymin);
+        ymax = std::max(y2, ymax);
 
-        for (Graph *pg : pd->Graphs)
+        for (Graph* pg : pd->Graphs) {
             // test all markers of diagram
-            for (Marker *pm : pg->Markers) {
+            for (Marker* pm : pg->Markers) {
                 pm->Bounding(x1, y1, x2, y2);
-                if (x1 < xmin)
-                    xmin = x1;
-                if (x2 > xmax)
-                    xmax = x2;
-                if (y1 < ymin)
-                    ymin = y1;
-                if (y2 > ymax)
-                    ymax = y2;
+                xmin = std::min(x1, xmin);
+                xmax = std::max(x2, xmax);
+                ymin = std::min(y1, ymin);
+                ymax = std::max(y2, ymax);
             }
+        }
     }
 
     // find boundings of all Paintings
-    for (pp = Paintings->first(); pp != nullptr; pp = Paintings->next()) {
+    for (auto* pp : *Paintings) {
         if (!pp->isSelected) {
             continue;
         }
         isAnySelected = true;
         pp->Bounding(x1, y1, x2, y2);
-        if (x1 < xmin)
-            xmin = x1;
-        if (x2 > xmax)
-            xmax = x2;
-        if (y1 < ymin)
-            ymin = y1;
-        if (y2 > ymax)
-            ymax = y2;
+        xmin = std::min(x1, xmin);
+        xmax = std::max(x2, xmax);
+        ymin = std::min(y1, ymin);
+        ymax = std::max(y2, ymax);
     }
 
     if (!isAnySelected) {
-        xmin = xmax = 0;
-        ymin = ymax = 0;
+        return QRect{};
     }
+
+    return QRect{xmin, ymin, xmax - xmin, ymax - ymin};
 }
 
 // ---------------------------------------------------
@@ -2534,14 +2467,15 @@ void Schematic::contentsDropEvent(QDropEvent *Event)
 
 #if QT_VERSION >= 0x060000
     auto ev_pos = Event->position();
+    QPoint inModel = contentsToModel(ev_pos.toPoint());
 #else
     auto ev_pos = Event->pos();
+    QPoint inModel = contentsToModel(ev_pos);
 #endif
     QMouseEvent e(QEvent::MouseButtonPress, ev_pos, Qt::LeftButton, Qt::NoButton, Qt::NoModifier);
-    int x = int(ev_pos.x() / Scale) + ViewX1;
-    int y = int(ev_pos.y() / Scale) + ViewY1;
 
-    App->view->MPressElement(this, &e, x, y);
+
+    App->view->MPressElement(this, &e, inModel.x(), inModel.y());
 
     delete App->view->selElem;
     App->view->selElem = nullptr; // no component selected
@@ -2676,183 +2610,4 @@ bool Schematic::checkDplAndDatNames()
         return false;
     }
     return false;
-}
-
-QRect Schematic::modelRect()
-{
-    return QRect{ViewX1, ViewY1, ViewX2 - ViewX1, ViewY2 - ViewY1};
-}
-
-QRect Schematic::viewportRect() {
-    return QRect{0, 0, viewport()->width(), viewport()->height()};
-}
-
-QPoint Schematic::viewportToModel(QPoint viewportCoordinates)
-{
-    viewportCoordinates.setX(contentsX() + viewportCoordinates.x());
-    viewportCoordinates.setY(contentsY() + viewportCoordinates.y());
-    return viewToModel(viewportCoordinates);
-}
-
-QPoint Schematic::viewToModel(const QPoint& coordinates)
-{
-    // Sizes in the model and view planes are interconnected and obey the rule:
-    //     <size in model plane> * <Scale> = <size in view plane>
-    //
-    // View plane is a rectangle with (0, 0) at its top-left corner. Model plane
-    // is rectangular area of abstract infinite plane, so model plane's top-left
-    // corner may have any coordinates.
-    //
-    // To transform coordinates of a point on the view plane to coordinates
-    // of corresponding point on model plane:
-    // 1. Adjust "view" coordinates so that they become having the same scale
-    //    the model plane has
-    // 2. Adjust resulting coordinates so they become absolute coordinates
-    //    in model plane
-
-    // QPoint overrides operator /. It divides both coordinates on given value
-    QPoint modelCoords = coordinates / Scale;
-
-    modelCoords.setX(ViewX1 + modelCoords.x());
-    modelCoords.setY(ViewY1 + modelCoords.y());
-    return modelCoords;
-}
-
-QPoint Schematic::modelToView(const QPoint& coordinates)
-{
-    // Sizes in the model and view planes are interconnected and obey the rule:
-    //     <size in model plane> * <Scale> = <size in view plane>
-    //
-    // View plane is a rectangle with (0, 0) at its top-left corner. Model plane
-    // is rectangular area of abstract infinite plane, so model plane's top-left
-    // corner may have any coordinates.
-    //
-    // To transform coordinates of a point on the model plane to coordinates
-    // of corresponding point on the view plane:
-    // 1. Adjust coordinates so that they become relative to model planes'
-    //    top-left corner
-    // 2. Adjust resulting coordinates so thay they become having the same scale
-    //    as view plane
-
-    QPoint viewCoords{coordinates.x() - ViewX1, coordinates.y() - ViewY1};
-    viewCoords *= Scale;
-    return viewCoords;
-}
-
-double Schematic::clipScale(double offeredScale)
-{
-    if (offeredScale > maxScale) {
-        return maxScale;
-    } else if (offeredScale < minScale) {
-        return minScale;
-    } else {
-       return offeredScale;
-    }
-}
-
-bool Schematic::shouldRender(const double& newScale, const QRect& newModelBounds, const QPoint& toBeDisplayed, const QPoint& viewportCoords) {
-    const QRect currentModelBounds = modelRect();
-    // This point currently displayed at "viewportCoords" of the viewport
-    const QPoint currenlyDisplayed = viewportToModel(viewportCoords);
-    return Scale != newScale || toBeDisplayed != currenlyDisplayed || currentModelBounds != newModelBounds;
-}
-
-double Schematic::renderModel(const double offeredScale, QRect newModel, const QPoint modelPoint, const QPoint viewportPoint)
-{
-    // This is the core method to render the schematic. It employs
-    // an approach similar to MVC (model-view-controller).
-    //
-    // There is a "model plane" – a rectangle located somewhere in some
-    // abstract cartesian coordinate system. This coordinate system has
-    // its X-axis directed left-to-right and Y-axis top-to-bottom. Every element
-    // of the schematic "lives" in this coordinate system inside the model
-    // plane. The model plane is described by class properties ViewX1, ViewY1,
-    // ViewX2, ViewY1.
-    //
-    // To see the schematic we need to "render" the model plane. To do so the
-    // "view plane" is used. Technically it is the Q3ScrollView's "contents",
-    // but in the abstraction being described its just another plane. In
-    // contrast to the model plane, its top-left corner is always (0,0), but the
-    // axes are directed the same way: left-to-right and top-to-bottom.
-    //
-    // The "scale" is the ratio between the view plane and model plane sizes.
-    // When being rendered, the model is like being "projected" on the view
-    // plane. Think of the film projector: the film ("model") could be displayed
-    // on screens ("views") of different sizes by adjusting the lense ("scale").
-    //
-    // Finally there is a "viewport". Technically its the very Q3ScrollView
-    // widget, but in the abstraction being described its the part of the
-    // view which is currently observed by the user. Sometimes the view is
-    // very large (when we "zoom in") and only the part of it could be observed.
-    //
-    // Summarizing everything said:
-    // 1. The model plane is drawn on the view plane at some scale and then
-    // a part of the view plane is observed by the user.
-    // 2. <size in model plane> * <Scale> = <size in view plane>
-
-    // DO NOT alter model bounds or scale and DO NOT call resizeContens() outside
-    // of this method. It will break the state and lead to hard-to-find bugs.
-    // Pass the desired model bounds or scale as the argument to this method.
-
-    assert(modelPoint.x() >= newModel.left() && modelPoint.x() <= newModel.right());
-    assert(modelPoint.y() >= newModel.top() && modelPoint.y() <= newModel.bottom());
-    assert(viewportPoint.x() >= 0 && viewportPoint.x() < viewport()->width());
-    assert(viewportPoint.y() >= 0 && viewportPoint.y() < viewport()->height());
-
-    // Maybe there is no need to do anything
-    const double newScale = clipScale(offeredScale);
-    if (!shouldRender(newScale, newModel, modelPoint, viewportPoint)) {
-       return Scale;
-    }
-
-    // The part below is quite tricky: while working at the model plane scale,
-    // we construct a "viewport" rectangle and position it so that it contains the
-    // area of the model, which should be displayed in the real viewport at the
-    // end. We do this because the "should-be-displayed" area might go beyond
-    // the model plane bounds, in which case the model plane size would have to
-    // be adjusted to include this area.
-    //
-    // Remember that <size in model plane> * <Scale> = <size in view plane>
-
-    QSize viewportSizeOnModelPlane = viewportRect().size() / newScale;
-
-    QPoint vpTopLeftOnModelPlane{
-        modelPoint.x() - static_cast<int>(std::round(viewportPoint.x() / newScale)),
-        modelPoint.y() - static_cast<int>(std::round(viewportPoint.y() / newScale))
-    };
-
-    QRect viewportOnModelPlane{vpTopLeftOnModelPlane, viewportSizeOnModelPlane};
-    newModel |= viewportOnModelPlane;
-
-    // At this point everything is ready for rendering and positioning
-
-    // Set new model size
-    ViewX1 = newModel.left();
-    ViewY1 = newModel.top();
-    ViewX2 = newModel.left() + newModel.width();
-    ViewY2 = newModel.top() + newModel.height();
-
-    Scale = newScale;
-    resizeContents(static_cast<int>(std::round(newModel.width() * Scale)),
-                   static_cast<int>(std::round(newModel.height() * Scale)));
-
-    auto contentTopLeft = modelToView(vpTopLeftOnModelPlane);
-    setContentsPos(contentTopLeft.x(), contentTopLeft.y());
-
-    viewport()->update();
-    App->view->drawn = false;
-
-    return Scale;
-}
-
-double Schematic::renderModel(const double offeredScale)
-{
-    const auto currentModelBounds = modelRect();
-    return renderModel(offeredScale, currentModelBounds,
-                       currentModelBounds.center(), viewportRect().center());
-}
-
-double Schematic::renderModel(const double offeredScale,const QPoint modelPoint, const QPoint viewportPoint)
-{
-    return renderModel(offeredScale, modelRect(), modelPoint, viewportPoint);
-}
+}
\ No newline at end of file
